@@ -42,11 +42,11 @@ Q_OBJECT
 		void clicked(QRgb, const QPoint&);
 	
 	protected:
-		void mousePressEvent(QMouseEvent *e);
-		void mouseMoveEvent(QMouseEvent *e);
-		void mouseReleaseEvent(QMouseEvent *e);
-		void wheelEvent(QWheelEvent *e);
-		void resizeEvent(QResizeEvent *e);
+		void mousePressEvent(QMouseEvent *e) override;
+		void mouseMoveEvent(QMouseEvent *e) override;
+		void mouseReleaseEvent(QMouseEvent *e) override;
+		void wheelEvent(QWheelEvent *e) override;
+		void resizeEvent(QResizeEvent *e) override;
 	
 	private:
 		/**
